#! /bin/sh

set -e

# $URL: https://svn.non-gnu.uvt.nl/uvt-dev/trunk/sources/meresco/harvester-1.0.0/bin/startharvester.sh $
# $Id: startharvester.sh 683 2009-02-13 14:49:01Z wsl $

case $# in 0)
	configfile=${0%.sh}.cf
;; *)
	configfile=$1
	shift
esac

# Make sure the scripts' directory becomes the current directory.
# This is only required if path variables must be relative to
# the script and the "startharvester.py" python script is called
# from the same directory. For some reason?

mydir=$(cd $(dirname $0) && pwd)

# configfile sets variables:
#	domain, logpath, saharaurl, sleeptime, statepath,
#	mailonerror, exitonerror

if [ ! -r $configfile ]
then
	echo "Error, file '$configfile' not found" >&2
	exit 1
fi

echo "Reading configfile: $configfile"
grep '^[^#]' $configfile
. $configfile

case $saharaurl in "http://localhost:908x")
	echo "ERROR: Uninitialized configurationfile!" >&2
	echo "The variable '\$saharaurl' was not correctly set." >&2
	echo "Please edit the file: $configfile" >&2
	exit 1
esac

test -d $logpath/$domain || mkdir -p $logpath/$domain

echo "Starting harvester loop"

while :
do
	echo "Running harvester"
	cd $mydir
	if ! python startharvester.py --logDir="$logpath" --stateDir="$statepath" --saharaurl="$saharaurl" --domain=$domain $configfile "$@"
	then
		case $mailonerror in '') ;; *)
			hostname=$(hostname)
			echo "Harvester failed for $(cat $configfile) at $hostname" |
				mail -s "harvester failed for: domain: $domain at host: $hostname" $mailonerror
		esac
		case $exitonerror in no) ;; *)
			exit 1
		esac
	fi

	echo "Done"

	cd $logpath/$domain
	for f in *.log *.events
	do
		if [ $(wc -l < $f) -gt 20000 ]
		then
			echo "Truncating logfile $f"
			tail -n 10000 $f > $f.tmp
			mv $f.tmp $f
		fi
	done

	case $sleeptime in '')
		echo "Single run mode, exiting"
		exit
	;; *)
		echo "Sleeping $sleeptime seconds"
		sleep $sleeptime
	esac
done
